@@ -1,17 +1,15 @@
-
-###################################################################################
-#' Select n Design Points
-#' 
-#' This function returns a subset of n design points.
+#' @title selectN. Select n Design Points
+#'
+#' @description  This function returns a subset of n design points.
 #'
 #' @param x matrix of design points
-#' @param y matrix of function values 
+#' @param y matrix of function values
 #' @param control list of controls
 #' \describe{
 #'		\item{\code{N}}{number of points to be returned.}
 #' }
-#' 
-#' 
+#'
+#'
 #' @return This function returns a list with n design points:
 #' \describe{
 #'		\item{\code{x}}{matrix of selected design points.}
@@ -21,14 +19,19 @@
 #' @export
 #' @keywords internal
 ###################################################################################
-selectN <- function(x, y, control){
+selectN <- function(x, y, control) {
   nx <- dim(x)[1]
   ny <- dim(y)[1]
-  try(if(nx != ny) stop("x and y matrices: different length"))
-  N <- ifelse( exists("N", where=control), control$N, nx) 
-  a <- nx-N+1
+  try(if (nx != ny)
+    stop("x and y matrices: different length"))
+  N <- ifelse(exists("N", where = control), control$N, nx)
+  a <- nx - N + 1
   b <- nx
-  ifelse (
-    N > min(nx, ny), return( list(x=x, y=y)), return(list( x= matrix( x[a:b, , drop = FALSE ], N, ), 
-                                                           y= matrix( y[a:b, , drop = FALSE ], N ,) )) )
+  if (N > min(nx, ny)) {
+    return(list(x = x, y = y))
+  }
+  else{
+    return(list(x = matrix(x[a:b, , drop = FALSE], N,),
+                y = matrix(y[a:b, , drop = FALSE], N,)))
+  }
 }
